using System;
using WingServerCommon.Log;
using WingServerCommon.Interfaces.OpLog;
namespace WingServerCommon.Interfaces.Cache
{
    public interface IDeviceInfosManager : IBaseCacheManager<CacheDeviceDTO>
    {

    }

    public class DeviceInfosManager : CacheManager<CacheDeviceDTO>, IDeviceInfosManager
    {
        public DeviceInfosManager() : base()
        {
        }
    }

    public class CacheDeviceDTO : ICacheObject
    {
        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>test0122</value>
        public string Code { get; set; }

        /// <summary>
        /// 设备序列号
        /// </summary>
        /// <value>test010122</value>
        public string SerialNumber { get; set; }

        /// <summary>
        /// 设备密码
        /// </summary>
        /// <value>ABC123</value>
        public string Password { get; set; }

        /// <summary>
        /// 设备名称
        /// </summary>
        /// <value>测试设备0122</value>
        public string Name { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        /// <value>测试Description22</value>
        public string Description { get; set; }

        /// <summary>
        /// 设备型号
        /// </summary>
        /// <value>M001</value>
        public string DeviceModel { get; set; }

        /// <summary>
        /// 设备类型
        /// </summary>
        /// <value>X00001</value>
        public string DeviceType { get; set; }

        /// <summary>
        /// 设备头图
        /// </summary>
        /// <value>http://192.168.6.117:9001/Storage/B1154C6500E4F174249224B41284498E_7_0_0_0.PNG</value>
        public string HeadPicUrl { get; set; }

        /// <summary>
        /// 设备软件版本
        /// </summary>
        /// <value>1.11.0</value>
        public string DeviceSoftwareVersion { get; set; }

        /// <summary>
        /// 设备SDK版本
        /// </summary>
        /// <value>1.11.1</value>
        public string SDKSoftwareVersion { get; set; }

        /// <summary>
        /// 设备所属组织
        /// </summary>
        /// <value>Organization_2022012520473430DnW3</value>
        public string OrganizationCode { get; set; }

        /// <summary>
        /// 组织下属科室
        /// </summary>
        /// <value>Organization_2022012520473430DnW32</value>
        public string DepartmentCode { get; set; }

        /// <summary>
        /// 超声机动态唯一码
        /// </summary>
        /// <value>test01010122</value>
        public string ShortCode { get; set; }

        /// <summary>
        /// 是否设备自动分享
        /// </summary>
        /// <value>true</value>
        public bool IsAutoShared { get; set; }

        /// <summary>
        /// 最近登录时间
        /// </summary>
        /// <value>2022-02-28T09:21:38.861Z</value>
        public DateTime LastLoginTime { get; set; } = DateTime.UtcNow;

        /// <summary>
        /// 系统版本
        /// </summary>
        /// <value>2.2.27.5</value>
        public string SystemVersion { get; set; } = string.Empty;

        /// <summary>
        /// CPU型号
        /// </summary>
        /// <value>I5-10400</value>
        public string CPUModel { get; set; } = string.Empty;

        /// <summary>
        /// 系统语言
        /// </summary>
        /// <value>Chinese</value>
        public string SystemLanguage { get; set; } = string.Empty;

        /// <summary>
        /// AI应用集合
        /// </summary>
        public List<string> DiagnosisModules { get; set; } = new();

        /// <summary>
        /// 报告转发配置集合
        /// </summary>
        public List<string> ReportPosterCodes { get; set; } = new();
    }
}